##  Unaddressed Risk Percentage
The unaddressed risk percentage view helps prioritize and tackle risks that still require attention. This view visualizes the percentage of IT components supporting each application with lifecycle information in Phase Out or End Of Life.
![Unaddressed Risk Percentage View](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2750d4317a441014bc95abc3a508ff03_LowRes.png)
Unaddressed Risk Percentage View
YesNo
Send
